<?php
if (!defined('ABSPATH')) {
    exit;
}
add_filter('gform_tooltips', array('GFJETLINEZNOTIFYZ_Pro_Settings', 'tooltips'));

class GFJETLINEZNOTIFYZ_Pro_Settings
{
    protected static function check_access($required_permission)
    {
        if (!function_exists('wp_get_current_user')) {
            include(ABSPATH . "wp-includes/pluggable.php");
        }
        return GFCommon::current_user_can_any($required_permission);
    }

    public static function tooltips($tooltips)
    {
        $tooltips["admin_default"] = __("You can set several numbers. Separate with commas(,). for example : +16175551212,+16175551213. this numbers is default and you can change them later.", "GF_JETLINEZ_NOTIFYZ");
        $tooltips["show_credit"] = __("Activating this section is not recommended; since you must connect to the webservice provider every time you wish to check your credit’s status and this might cause the wordpress admin to reduce in speed.", "GF_JETLINEZ_NOTIFYZ");
        $tooltips["country_code"] = __("Your Mobile Country code. like : +1", "GF_JETLINEZ_NOTIFYZ");
        $tooltips["gf_notifyz_sender"] = __("Separate with commas (,)", "GF_JETLINEZ_NOTIFYZ");
        $tooltips["show_adminbar"] = __("Show Gravity forms Notifyz menu in adminbar?", "GF_JETLINEZ_NOTIFYZ");
        $tooltips["sidebar_ajax"] = __("Activate this option to replace merge tags value in Notifyz Sidebar via ajax (Entry details)", "GF_JETLINEZ_NOTIFYZ");
        return $tooltips;
    }

    public static function settings()
    {
        wp_enqueue_script('GF_JETLINEZ_NOTIFYZ_Chosen', GF_JETLINEZ_NOTIFYZ_URL . '/assets/chosen_v1.8.5/chosen.jquery.min.js', array(), true);
        wp_enqueue_style('GF_JETLINEZ_NOTIFYZ_Chosen', GF_JETLINEZ_NOTIFYZ_URL . '/assets/chosen_v1.8.5/chosen.min.css');
        $settings = GFJETLINEZNOTIFYZ_Pro::get_option();
        $G_code = rgget('gateway') ? rgget('gateway') : (!empty($settings["ws"]) ? $settings["ws"] : '');
        $G_code = strtolower($G_code);
        $gateway_options = get_option("gf_jetlineznotifyz_" . $G_code);
        if (!rgempty("uninstall")) {
            check_admin_referer("uninstall", "gf_jetlineznotifyz_uninstall");
            if (!self::check_access("gravityforms_jetlineznotifyz_uninstall")) {
                die(__("You don't have adequate permission to uninstall Gravity Notifyz Pro.", "GF_JETLINEZ_NOTIFYZ"));
            } else {
                GFJETLINEZNOTIFYZ_Pro_SQL::drop_table();
                delete_option("gf_notifyz_settings");
                delete_option("gf_notifyz_version");
                delete_option("gf_notifyz_installed");
                delete_option("gf_jetlinez_notifyz_last_sender");
                foreach ((array)GFJETLINEZNOTIFYZ_Pro_WebServices::get() as $code => $name) {
                    delete_option("gf_jetlineznotifyz_" . strtolower($code));
                }
                $plugin = GF_JETLINEZ_NOTIFYZ_DIR . "/jetlinez_notifyz_pro_gv.php";
                update_option('recently_activated', array($plugin => time()) + (array)get_option('recently_activated'));
                deactivate_plugins($plugin); ?>

                <div class="updated fade" style="padding:20px;">
                    <?php
                    echo sprintf(__("Gravity Forms Notifyz Pro have been successfully uninstalled. It can be re-activated from the %splugins page%s.", "GF_JETLINEZ_NOTIFYZ"), "<a href='plugins.php'>", "</a>") ?>
                </div>

                <?php
            }
            return false;
        } else if (!rgempty("gf_jetlineznotifyz_submit")) {
            check_admin_referer("update", "gf_jetlineznotifyz_update");
            $settings = array("appkey" => rgpost("gf_jetlineznotifyz_appkey"), "authkey" => rgpost("gf_jetlineznotifyz_authkey"), "from" => rgpost("gf_jetlineznotifyz_from"), "code" => rgpost("gf_jetlineznotifyz_code"), "to" => rgpost("gf_jetlineznotifyz_to"), "ws" => rgpost("gf_jetlineznotifyz_ws"), "cr" => rgpost("gf_jetlineznotifyz_showcr"), "menu" => rgpost("gf_jetlineznotifyz_menu"), "sidebar_ajax" => rgpost("gf_jetlineznotifyz_sidebar_ajax"));
            update_option("gf_notifyz_settings", array_map('sanitize_text_field', $settings));
            if (rgpost("gf_jetlineznotifyz_ws") && rgpost("gf_jetlineznotifyz_ws") != 'no') {
                $Saved_Gateway = 'GFJETLINEZNOTIFYZ_Pro_' . strtoupper(sanitize_text_field(rgpost("gf_jetlineznotifyz_ws")));
                if (class_exists($Saved_Gateway) && method_exists($Saved_Gateway, 'options')) {
                    $gateway_options = array();
                    foreach ((array)$Saved_Gateway::options() as $option => $name) {
                        $gateway_options[$option] = sanitize_text_field(rgpost("gf_jetlineznotifyz_" . strtolower(sanitize_text_field(rgpost("gf_jetlineznotifyz_ws"))) . '_' . $option));
                    }
                    update_option("gf_jetlineznotifyz_" . strtolower(sanitize_text_field(rgpost("gf_jetlineznotifyz_ws"))), $gateway_options);
                }
            }
            if (!headers_sent()) {
                wp_redirect(admin_url('admin.php?page=gf_settings&subview=gf_jetlinez_notifyz_pro&updated=true'));
                exit;
            }
        }
        if (rgget('updated') == 'true') {
            echo '<div class="updated fade" style="padding:6px">' . __("Settings updated.", "GF_JETLINEZ_NOTIFYZ") . '</div>';
        } ?>

        <form method="post" action="">

            <?php wp_nonce_field("update", "gf_jetlineznotifyz_update") ?>

            <h3><span><i
                            class="fa fa fa-mobile"></i><?php echo '   ' . __("Gravity Notifyz Pro settings", "GF_JETLINEZ_NOTIFYZ") . '   '; ?></span>
            </h3>

            <?php
            if (!empty($G_code) && $G_code != 'no') {
                if ($G_code == strtolower($settings["ws"]) && $credit = GFJETLINEZNOTIFYZ_Pro::credit(true)) {
                    preg_match('/([\d]+)/', $credit, $match);
                    $credit_int = isset($match[0]) ? $match[0] : $credit;
                    $range = GFJETLINEZNOTIFYZ_Pro::range();
                    $max = isset($range["max"]) ? $range["max"] : 500;
                    $min = isset($range["min"]) ? $range["min"] : 2;
                    if (intval($credit_int) >= $max) {
                        $color = '#008000';
                    } else if (intval($credit_int) < $max && intval($credit_int) >= $min) {
                        $color = '#FFC600';
                    } else {
                        $color = '#FF1454';
                    } ?>

                    <h5><?php _e("Your Notifyz Credit : ", "GF_JETLINEZ_NOTIFYZ") ?><span
                                style="color:<?php echo $color; ?> !important;"><?php echo $credit; ?></span></h5>

                    <?php
                }
            } ?>

            <hr/>

            <table class="form-table">

                <tr>
                    <th scope="row"><label
                                for="gf_jetlineznotifyz_ws"><?php _e("Notifyz Gateway", "GF_JETLINEZ_NOTIFYZ"); ?></label></th>

                    <td width="340">
                        <select id="gf_jetlineznotifyz_ws" name="gf_jetlineznotifyz_ws" style="width:100%;"
                                class="select-gateway<?php echo is_rtl() ? " chosen-rtl" : ""; ?>"
                                onchange="GF_SwitchGateway(jQuery(this).val());">

                            <?php foreach ((array)GFJETLINEZNOTIFYZ_Pro_WebServices::get() as $code => $name) { ?>

                                <option style="padding:3px"
                                        value="<?php echo $code ?>" <?php echo esc_attr($G_code) == $code ? "selected='selected'" : "" ?>><?php echo $name ?></option>

                            <?php } ?>

                        </select>
                    </td>

                    <td rowspan="2" valign="middle">
                    </td>
                </tr>


                <?php
                if (!empty($G_code) && $G_code != 'no') {
                    $Gateway = 'GFJETLINEZNOTIFYZ_Pro_' . strtoupper($G_code);
                    if (class_exists($Gateway) && method_exists($Gateway, 'options')) {
                        $flag = true;
                        foreach ((array)$Gateway::options() as $option => $name) { ?>
                            <tr>
                                <th scope="row"><label
                                            for="gf_jetlineznotifyz_<?php echo $G_code . '_' . $option; ?>"><?php echo $name; ?></label>
                                </th>
                                <td width="340">
                                    <input type="text" id="gf_jetlineznotifyz_<?php echo $G_code . '_' . $option; ?>"
                                           name="gf_jetlineznotifyz_<?php echo $G_code . '_' . $option; ?>"
                                           value="<?php echo esc_attr($gateway_options[$option]) ?>" size="50"
                                           style="padding: 5px; direction:ltr !important;text-align:left;"/>
                                </td>
                                <td rowspan="2" valign="middle">
                                </td>
                            </tr>
                        <?php }
                    }
                } ?>

<!--                <tr>-->
<!--                    <th scope="row">-->
<!--                        <label for="gf_jetlineznotifyz_from">-->
<!--                            --><?php //_e("Sender (From)", "GF_JETLINEZ_NOTIFYZ"); ?>
<!--                            --><?php //gform_tooltip('gf_notifyz_sender') ?>
<!--                        </label>-->
<!---->
<!--                    </th>-->
<!--                    <td width="340">-->
<!---->
<!--                        <input type="text" id="gf_jetlineznotifyz_from" name="gf_jetlineznotifyz_from"-->
<!--                               value="--><?php //echo esc_attr($settings["from"]) ?><!--" size="50"-->
<!--                               style="padding: 5px; direction:ltr !important;text-align:left;"/><br/>-->
<!--                    </td>-->
<!--                </tr>-->


                <tr>
                    <th scope="row">
                        <label for="gf_jetlineznotifyz_code">
                            <?php _e("Your Default Country Code", "GF_JETLINEZ_NOTIFYZ"); ?>
                            <?php gform_tooltip('country_code') ?>
                        </label>
                    </th>
                    <td width="340">

                        <input type="text" id="gf_jetlineznotifyz_code" name="gf_jetlineznotifyz_code"
                               value="<?php echo esc_attr($settings["code"]) ?>" size="50"
                               style="padding: 5px; direction:ltr !important;text-align:left;"/><br/>

                    </td>
                </tr>


                <!-- <tr>
                    <th scope="row">
                        <label for="gf_jetlineznotifyz_to">
							<?php ?>
							<?php ?>
                        </label>
                    </th>
                    <td width="340">

                        <input type="text" id="gf_jetlineznotifyz_to" name="gf_jetlineznotifyz_to"
                               value="<?php ?>" size="50"
                               style="padding: 5px; direction:ltr !important;text-align:left;"/><br/>

                    </td>
                </tr>-->

<!--                --><?php //if (!empty($flag) && !empty($Gateway) && $Gateway::credit()) { ?>

<!--                    <tr>-->
<!--                        <th scope="row">-->
<!--                            <label for="gf_jetlineznotifyz_showcr">-->
<!--                                --><?php //_e("Show Credit/Balance", "GF_JETLINEZ_NOTIFYZ"); ?>
<!--                                --><?php //gform_tooltip('show_credit') ?>
<!--                            </label>-->
<!--                        </th>-->
<!--                        <td width="340">-->
<!---->
<!---->
<!--                            <input type="radio" name="gf_jetlineznotifyz_showcr" id="gf_jetlineznotifyz_showcr_show"-->
<!--                                   value="Show" --><?php //echo esc_attr($settings["cr"]) == "Show" ? "checked='checked'" : "" ?><!--/>-->
<!--                            <label class="inline"-->
<!--                                   for="gf_jetlineznotifyz_showcr_show">--><?php //_e("Yes", "GF_JETLINEZ_NOTIFYZ"); ?><!--</label>&nbsp;&nbsp;&nbsp;-->
<!---->
<!--                            <input type="radio" name="gf_jetlineznotifyz_showcr" id="gf_jetlineznotifyz_showcr_no"-->
<!--                                   value="No" --><?php //echo esc_attr($settings["cr"]) != "Show" ? "checked='checked'" : "" ?><!--/>-->
<!--                            <label class="inline"-->
<!--                                   for="gf_jetlineznotifyz_showcr_no">--><?php //_e("No ( Recommended )", "GF_JETLINEZ_NOTIFYZ"); ?><!--</label>-->
<!---->
<!--                            <br/>-->
<!---->
<!--                        </td>-->
<!--                    </tr>-->

<!--                    --><?php
//                } ?>

                <tr>
                    <th scope="row">
                        <label for="gf_jetlineznotifyz_menu">
                            <?php _e("Admin Bar Menu", "GF_JETLINEZ_NOTIFYZ"); ?>
                            <?php gform_tooltip('show_adminbar') ?>
                        </label>
                    </th>
                    <td width="340">


                        <input type="radio" name="gf_jetlineznotifyz_menu" id="gf_jetlineznotifyz_menu_show"
                               value="Show" <?php echo esc_attr($settings["menu"]) == "Show" ? "checked='checked'" : "" ?>/>
                        <label class="inline"
                               for="gf_jetlineznotifyz_menu_show"><?php _e("Yes", "GF_JETLINEZ_NOTIFYZ"); ?></label>&nbsp;&nbsp;&nbsp;


                        <input type="radio" name="gf_jetlineznotifyz_menu" id="gf_jetlineznotifyz_menu_no"
                               value="No" <?php echo esc_attr($settings["menu"]) != "Show" ? "checked='checked'" : "" ?>/>
                        <label class="inline"
                               for="gf_jetlineznotifyz_menu_no"><?php _e("No", "GF_JETLINEZ_NOTIFYZ"); ?></label>

                        <br/>

                    </td>
                </tr>


                <tr>
                    <th scope="row">
                        <label for="gf_jetlineznotifyz_sidebar_ajax">
                            <?php _e("Replace merge tags value in Notifyz Sidebar", "GF_JETLINEZ_NOTIFYZ"); ?>
                            <?php gform_tooltip('sidebar_ajax') ?>
                        </label>
                    </th>
                    <td width="340">


                        <input type="radio" name="gf_jetlineznotifyz_sidebar_ajax" id="gf_jetlineznotifyz_sidebar_ajax_Yes"
                               value="Yes" <?php echo empty($settings["sidebar_ajax"]) || esc_attr($settings["sidebar_ajax"]) != "No" ? "checked='checked'" : "" ?>/>
                        <label class="inline"
                               for="gf_jetlineznotifyz_sidebar_ajax_Yes"><?php _e("Yes", "GF_JETLINEZ_NOTIFYZ"); ?></label>&nbsp;&nbsp;&nbsp;

                        <input type="radio" name="gf_jetlineznotifyz_sidebar_ajax" id="gf_jetlineznotifyz_sidebar_ajax_no"
                               value="No" <?php echo !empty($settings["sidebar_ajax"]) && esc_attr($settings["sidebar_ajax"]) == "No" ? "checked='checked'" : "" ?>/>
                        <label class="inline"
                               for="gf_jetlineznotifyz_sidebar_ajax_no"><?php _e("No", "GF_JETLINEZ_NOTIFYZ"); ?></label>

                        <br/>

                    </td>
                </tr>


                <tr>
                    <th scope="row">
                        <input type="submit" name="gf_jetlineznotifyz_submit" class="button-primary"
                               value="<?php _e("Save Settings", "GF_JETLINEZ_NOTIFYZ") ?>"/>
                    </th>
                </tr>

            </table>


        </form>
        <form action="" method="post">
            <?php wp_nonce_field("uninstall", "gf_jetlineznotifyz_uninstall") ?>
            <?php if (self::check_access("gravityforms_jetlineznotifyz_uninstall")) { ?>

                <div class="hr-divider"></div>
                <div class="delete-alert alert_red">
                    <h3><?php _e("Uninstall Gravity Forms Notifyz Pro", "GF_JETLINEZ_NOTIFYZ") ?></h3>
                    <div
                            class="gf_delete_notice"><?php _e("<strong>Warning!</strong> This operation deletes ALL Gravity Notifyz Pro Informations.", "GF_JETLINEZ_NOTIFYZ") ?></div>
                    <input type="submit" name="uninstall"
                           value="<?php _e("Uninstall Gravity Forms Notifyz Pro", "GF_JETLINEZ_NOTIFYZ") ?>" class="button"
                           onclick="return confirm('<?php _e("Warning! ALL Gravity Notifyz Pro informations will be deleted. This cannot be undone. \'OK\' to delete, \'Cancel\' to stop", "GF_JETLINEZ_NOTIFYZ") ?>'); "/>
                </div>
            <?php } ?>
        </form>


        <script type="text/javascript">
            function GF_SwitchGateway(code) {
                new_query = "gateway=" + code;
                document.location = document.location + "&" + new_query;
            }

            jQuery(document).ready(function () {
                jQuery(".select-gateway").chosen();
            });
        </script>
        <?php
    }
}

if (defined('GF_JETLINEZ_NOTIFYZ_GATEWAY')) {
    $files = scandir(GF_JETLINEZ_NOTIFYZ_GATEWAY);
    if ($files) {
        foreach ((array)$files as $file) {
            $path_parts = pathinfo(GF_JETLINEZ_NOTIFYZ_GATEWAY . $file);
            if (strpos($file, '.php')) {
                include 'gateways/' . $path_parts['filename'] . '.php';
                $Gateway = 'GFJETLINEZNOTIFYZ_Pro_' . strtoupper($path_parts['filename']);
                if (class_exists($Gateway)) {
                    if (method_exists($Gateway, 'options') && method_exists($Gateway, 'process') && method_exists($Gateway, 'name')) {
                        add_filter('gf_jetlinez_notifyz_gateways', array($Gateway, 'name'));
                    }
                }
            }
        }
    }
}